@@ -1,6 +1,6 @@
 package GD::Icons;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 # $Id: Icons.pm,v 1.8 2007/08/06 15:36:54 canaran Exp $
 
@@ -784,13 +784,13 @@ Methods:
 
 =head1 AUTHOR
 
-Payan Canaran <canaran@cshl.edu>
+Payan Canaran <pcanaran@cpan.org>
 
 =head1 BUGS
 
 =head1 VERSION
 
-Version 0.03
+Version 0.04
 
 =head1 ACKNOWLEDGEMENTS
 
